from django.conf.urls import url

from . import views

urlpatterns = [
    # ex: /polls/
    url(r'^$', views.index, name='index'),
    url(r'^code_base_info/$', views.code_base_info, name='code_base_info'),
    
]



from django.shortcuts import render,HttpResponse,render_to_response
from django.conf import settings
import json,os
# Create your views here.

def get_views(app):
    list1 = []
    views_file = os.path.join(settings.BASE_DIR,app,'views.py')
    for line in file(views_file):
	if line.startswith('def'):
	    list1.append(line[4:line.index('(')])
    return list1

def index(request):
    return render_to_response('django_universe/code_base.html',{})

def code_base_info(request):
    views_dict = {}
    apps = settings.APPS_FOR_UNIVERSE
    for app in apps:
	
	#views
	views_dict[app] = get_views(app)
    dict1 = {}
    dict1['views'] = views_dict
    return HttpResponse(json.dumps(dict1))



import os
from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()

setup(
    name='django_universe',
    version='3.9',
    packages=['django_universe'],
    description='A line of description for v0.8',
    long_description=README,
    include_package_data=True, 
    author='jerin',
    author_email='jerinzam@gmail.com',
    url='https://github.com/jerinzam/django-universe/',
    download_url='https://github.com/jerinzam/django-universe/tarball/0.8',
    license='MIT',
    install_requires=[
        'Django==1.9.9',
    ]
)
